<?php
/*
Plugin Name: Front-End Theme Changer PersianScript.ir
Description: A plugin, which lets your users select the theme they like most.
Version: 1.0.0
Author: PersianScript.ir
Author URI: http://PersianScript.ir
*/

if (!defined('ABSPATH'))
    die();

if(!function_exists('get_current_screen'))
    include(ABSPATH . "wp-admin/includes/screen.php");

define('ORAK_CTPL_OPTIONS_PAGE_NAME', 'orak_ctpl_settings');
define('ORAK_CTPL_OPTION_GROUP', 'orak_ctpl_opt_group');
define('ORAK_CTPL_OPTION_NAME', 'orak_ctpl_vars');
define('ORAK_CTPL_TEXTDOMAIN', 'orak_ctpl_textdomain');
		  
class OrakTC_widget extends WP_widget
{
	public function __construct() 
	{
		parent::__construct('orak_theme_changer', __('Theme Changer (oraksoft)', ORAK_CTPL_TEXTDOMAIN));
	}
	
	public function widget( $args, $instance ) 
	{
	    extract( $args );
		
		$opts = get_option(ORAK_CTPL_OPTION_NAME);
		
		echo $before_widget;
		echo $before_title.$opts['widget_title'].$after_title;
		echo get_theme_switcher_form();
		echo $after_widget;
	}
}

function get_theme_switcher_form()
{
	$opts = get_option(ORAK_CTPL_OPTION_NAME);
	$form  = '<style>'.$opts['custom_css'].'</style>';
	$form .= '<form method="post" action="" id="orak_theme_changer_form">';
	$form .= '<select name="orak_theme">';
	foreach($opts['themes_array'] as $key => $theme)
	{
		if(array_key_exists($key, (array)wp_get_themes()))
		{
			$form .= '<option value='.$key.' '.($theme == wp_get_theme() ? 'selected' : '').'>'.$theme.'</option>';
		}
	}
	$form .= '</select>';
	$form .= '<input type="submit" name="orak_change_theme" value="'.$opts['button_title'].'"/>';
	$form .= '</form>';
	
	return $form;
}

function orak_load_widget() 
{
    register_widget('OrakTC_widget');
}

function orak_ctpl_templatestylesheet_callback($default_theme) 
{
	$opts = get_option(ORAK_CTPL_OPTION_NAME);
	if(!isset($_COOKIE['oraksoft_theme']) || $_COOKIE['oraksoft_theme'] == '' || !array_key_exists($_COOKIE['oraksoft_theme'], (array)wp_get_themes()) || !array_key_exists($_COOKIE['oraksoft_theme'], $opts['themes_array'])) 
	{
		unset($_COOKIE['oraksoft_theme']);
		return $default_theme;
	} 
	else 
	{
		return $_COOKIE['oraksoft_theme'];
	}
}

function orak_ctpl_admin_init()
{
	register_setting(ORAK_CTPL_OPTION_GROUP, ORAK_CTPL_OPTION_NAME);
}

function orak_ctpl_submit() 
{
	if(isset($_POST['orak_ctpl_clear_themes_cache']))
	{
		unset($_COOKIE['oraksoft_theme']);
		setcookie("oraksoft_theme", '_DEFAULT_', 1, '/');
	}
	
	if(isset($_POST['orak_change_theme']))
	{
		if(isset($_POST['orak_theme']) && array_key_exists($_POST['orak_theme'], (array)wp_get_themes()))
		{
			setcookie("oraksoft_theme", '', 1, '/');
			setcookie("oraksoft_theme", strtolower($_POST['orak_theme']), time()+3600*24*365, '/');
			
			add_filter('stylesheet', 'orak_ctpl_templatestylesheet_callback');
			add_filter('template', 'orak_ctpl_templatestylesheet_callback');
			
			header("Location: ".$_SERVER['REQUEST_URI']);
			exit;
		}
	}
	
	if(!strstr($_SERVER['REQUEST_URI'], 'wp-admin/themes'))
	{
		add_filter('stylesheet', 'orak_ctpl_templatestylesheet_callback');
		add_filter('template', 'orak_ctpl_templatestylesheet_callback');
	}
}

function orak_ctpl_install()
{
	add_option(ORAK_CTPL_OPTION_NAME,  array(
					'themes_array' => wp_get_themes(),
					'widget_title' => __('Choose theme', ORAK_CTPL_TEXTDOMAIN), 
					'button_title' => __('Change', ORAK_CTPL_TEXTDOMAIN),
					'custom_css' => '#orak_theme_changer_form select, input { display:block; margin-bottom: 10px; }'
				));
}

function orak_ctpl_uninstall()
{
	delete_option(ORAK_CTPL_OPTION_NAME);
	unset($_COOKIE['oraksoft_theme']);
	setcookie("oraksoft_theme", '_DEFAULT_', 1, '/');
}

function orak_ctpl_menu_contents() 
{
	include plugin_dir_path(__FILE__).'includes/admin-settings.php';
}

function orak_ctpl_settings()
{
	add_menu_page(__('OrakSoft: Front-End Theme Changer', ORAK_CTPL_TEXTDOMAIN), __('Front-End Theme Changer', ORAK_CTPL_TEXTDOMAIN), 'manage_options', 'orak_ctpl', 'orak_ctpl_menu_contents', plugins_url('orak-ctpl-icon.png', __FILE__) );
			
	add_filter("plugin_action_links_".plugin_basename(__FILE__), function($links) { 
		$settings_link = '<a href="admin.php?page=orak_ctpl">'.__('Settings', ORAK_CTPL_TEXTDOMAIN).'</a>'; 
		array_unshift($links, $settings_link); 
		return $links; 
	} );
}


add_action('widgets_init', 'orak_load_widget' );
add_action('admin_init', 'orak_ctpl_admin_init');
add_action('plugins_loaded', 'orak_ctpl_submit');
add_action('admin_menu', 'orak_ctpl_settings');

add_shortcode('oraksoft_theme_changer', 'get_theme_switcher_form');

register_activation_hook(__FILE__, 'orak_ctpl_install');
register_deactivation_hook(__FILE__, 'orak_ctpl_uninstall');
?>